@@ -1,9 +1,13 @@
 package MooseX::Singleton::Role::Meta::Instance;
+BEGIN {
+  $MooseX::Singleton::Role::Meta::Instance::AUTHORITY = 'cpan:SARTAK';
+}
+BEGIN {
+  $MooseX::Singleton::Role::Meta::Instance::VERSION = '0.26';
+}
 use Moose::Role;
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.25';
-$VERSION = eval $VERSION;
 
 sub get_singleton_instance {
     my ( $self, $instance ) = @_;
@@ -63,7 +67,9 @@ no Moose::Role;
 
 1;
 
-__END__
+# ABSTRACT: Instance metaclass role for MooseX::Singleton
+
+
 
 =pod
 
@@ -71,10 +77,29 @@ __END__
 
 MooseX::Singleton::Role::Meta::Instance - Instance metaclass role for MooseX::Singleton
 
+=head1 VERSION
+
+version 0.26
+
 =head1 DESCRIPTION
 
 This role overrides all object access so that it gets the appropriate
 singleton instance for the class.
 
+=head1 AUTHOR
+
+Shawn M Moore <sartak@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2001 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
+
